createSimpleImputer: Create Simple Imputer settings

View source: R/Imputation.R

createSimpleImputerR Documentation

Create Simple Imputer settings

Description

This function creates the settings for a simple imputer which imputes missing values with the mean or median

Usage

createSimpleImputer(
  method = "mean",
  missingThreshold = 0.3,
  addMissingIndicator = FALSE
)

Arguments

method

The method to use for imputation, either "mean" or "median"

missingThreshold

The threshold for missing values to be imputed vs removed

addMissingIndicator

Add a binary missingness indicator per feature that passes the imputation missingness threshold.

Value

The settings for the single imputer of class featureEngineeringSettings

Examples

# create imputer to impute values with missingness less than 10% using the median
# of observed values
createSimpleImputer(method = "median", missingThreshold = 0.10)

PatientLevelPrediction documentation built on March 9, 2026, 5:07 p.m.