View source: R/HyperparameterSettings.R
| createTuningMetric | R Documentation |
Create a tuning metric descriptor
createTuningMetric(fun, maximize = TRUE, name, funArgs = list())
fun |
Function (or function name) that returns a single numeric score when given a prediction data frame. |
maximize |
Logical; TRUE if larger is better. |
name |
Friendly name for logs and summaries. |
funArgs |
Optional named list of extra arguments passed to |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.