listCartesian: Cartesian product

View source: R/HyperparameterSettings.R

listCartesianR Documentation

Cartesian product

Description

Computes the Cartesian product of all the combinations of elements in a list

Usage

listCartesian(allList)

Arguments

allList

a list of lists

Value

A list with all possible combinations from the input list of lists

Examples

listCartesian(list(list(1, 2), list(3, 4)))

PatientLevelPrediction documentation built on March 9, 2026, 5:07 p.m.