View source: R/LearningCurve.R
| plotLearningCurve | R Documentation |
Create a plot of the learning curve using the object returned
from createLearningCurve.
plotLearningCurve( learningCurve, metric = "AUROC", abscissa = "events", plotTitle = "Learning Curve", plotSubtitle = NULL, fileName = NULL )
learningCurve |
An object returned by |
metric |
Specifies the metric to be plotted:
|
abscissa |
Specify the abscissa metric to be plotted:
|
plotTitle |
Title of the learning curve plot. |
plotSubtitle |
Subtitle of the learning curve plot. |
fileName |
Filename of plot to be saved, for example |
A ggplot object. Use the ggsave function to save to
file in a different format.
## Not run:
# create learning curve object
learningCurve <- createLearningCurve(population,
plpData,
modelSettings)
# plot the learning curve
plotLearningCurve(learningCurve)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.