View source: R/HyperparameterSettings.R
| prepareHyperparameterGrid | R Documentation |
Prepare Hyperparameter
prepareHyperparameterGrid(paramDefinition, hyperSettings)
paramDefinition |
A list defining the hyperparameters and their possible values. |
hyperSettings |
An object of class |
An iterator object with methods to get the next hyperparameter combination and finalize the search.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.