computeAuprc: Compute the area under the Precision-Recall curve

View source: R/EvaluationSummary.R

computeAuprcR Documentation

Compute the area under the Precision-Recall curve

Description

Compute the area under the Precision-Recall curve

Usage

computeAuprc(prediction)

Arguments

prediction

A prediction object as generated using the predict functions.

Details

Computes the area under the Precision-Recall curve for the predicted scores, given the true observed outcomes.

Value

A numeric value containing the AUPRC

Examples

prediction <- data.frame(
  value = c(0.1, 0.2, 0.3, 0.4, 0.5),
  outcomeCount = c(0, 1, 0, 1, 1))
computeAuprc(prediction)

PatientLevelPrediction documentation built on March 9, 2026, 5:07 p.m.