powered by
Compute the area under the Precision-Recall curve
computeAuprc(prediction)
A numeric value containing the AUPRC
A prediction object as generated using the predict functions.
predict
Computes the area under the Precision-Recall curve for the predicted scores, given the true observed outcomes.
prediction <- data.frame( value = c(0.1, 0.2, 0.3, 0.4, 0.5), outcomeCount = c(0, 1, 0, 1, 1)) computeAuprc(prediction)
Run the code above in your browser using DataLab