powered by
This function creates the settings for a simple imputer which imputes missing values with the mean or median
createSimpleImputer( method = "mean", missingThreshold = 0.3, addMissingIndicator = FALSE )
The settings for the single imputer of class featureEngineeringSettings
featureEngineeringSettings
The method to use for imputation, either "mean" or "median"
The threshold for missing values to be imputed vs removed
Add a binary missingness indicator per feature that passes the imputation missingness threshold.
# create imputer to impute values with missingness less than 10% using the median # of observed values createSimpleImputer(method = "median", missingThreshold = 0.10)
Run the code above in your browser using DataLab