Create scikit-learn Iterative Imputer settings
Source:R/Imputation.R
createSklearnIterativeImputer.RdThis function creates settings for a dense iterative imputer
powered by scikit-learn's IterativeImputer through reticulate.
Usage
createSklearnIterativeImputer(
missingThreshold = 0.3,
methodSettings = list(),
addMissingIndicator = FALSE
)Arguments
- missingThreshold
The threshold for missing values to remove a feature
- methodSettings
A list of settings for sklearn
IterativeImputer. Supported settings are:maxIter
tol
samplePosterior
nNearestFeatures
initialStrategy
imputationOrder
skipComplete
randomState
minValue
maxValue
- addMissingIndicator
Add a binary missingness indicator per feature that passes the imputation missingness threshold.