| createSklearnIterativeImputer | R Documentation |
This function creates settings for a dense iterative imputer
powered by scikit-learn's IterativeImputer through reticulate.
createSklearnIterativeImputer(
missingThreshold = 0.3,
methodSettings = list(),
addMissingIndicator = FALSE
)
missingThreshold |
The threshold for missing values to remove a feature |
methodSettings |
A list of settings for sklearn
|
addMissingIndicator |
Add a binary missingness indicator per feature that passes the imputation missingness threshold. |
The settings for the sklearn iterative imputer of class featureEngineeringSettings
## Not run:
createSklearnIterativeImputer(
missingThreshold = 0.3,
methodSettings = list(maxIter = 5, nNearestFeatures = 20)
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.