powered by
This function creates settings for a dense iterative imputer powered by scikit-learn's IterativeImputer through reticulate.
IterativeImputer
reticulate
createSklearnIterativeImputer( missingThreshold = 0.3, methodSettings = list(), addMissingIndicator = FALSE )
The settings for the sklearn iterative imputer of class featureEngineeringSettings
featureEngineeringSettings
The threshold for missing values to remove a feature
A list of settings for sklearn IterativeImputer. Supported settings are:
maxIter
tol
samplePosterior
nNearestFeatures
initialStrategy
imputationOrder
skipComplete
randomState
minValue
maxValue
Add a binary missingness indicator per feature that passes the imputation missingness threshold.
# dontrun reason: requires python and scikit-learn if (FALSE) { createSklearnIterativeImputer( missingThreshold = 0.3, methodSettings = list(maxIter = 5, nNearestFeatures = 20) ) }
Run the code above in your browser using DataLab