| fitPlp | R Documentation |
Train various models using a default parameter gird search or user specified parameters
fitPlp(trainData, modelSettings, search = "grid", analysisId)
trainData |
An object of type |
modelSettings |
An object of class
|
search |
The search strategy for the hyper-parameter selection (currently not used) |
analysisId |
The id of the analysis |
The user can define the machine learning model to train (regularised logistic regression, random forest, gradient boosting machine, neural network and )
An object of class plpModel containing:
model |
The trained prediction model |
modelLoc |
The path to where the model is saved (if saved) |
trainAuc |
The AUC obtained on the training set |
trainCalibration |
The calibration obtained on the training set |
modelSettings |
A list specifiying the model, preprocessing, outcomeId and cohortId |
metaData |
The model meta data |
trainingTime |
The time taken to train the classifier |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.