Learn R Programming

PatientLevelPrediction (version 6.7.0)

setPythonEnvironment: Select a manually configured Python environment

Description

Select a manually configured Python environment

Usage

setPythonEnvironment(envname = "PLP", envtype = NULL)

Value

A string indicating which Python environment will be used

Arguments

envname

A string for the name of the virtual environment (default is 'PLP')

envtype

An option for specifying the environment as 'conda' or 'python'. If NULL then the default is 'conda' for Windows users and 'python' for non-Windows users

Details

This function sets PatientLevelPrediction to use a Python environment created using configurePython() or another manual environment setup.

Examples

Run this code
 # dontrun reason: don't modify environment in examples 
if (FALSE) {
# create a conda environment named PLP
configurePython(envname="PLP", envtype="conda")
}

Run the code above in your browser using DataLab